@@ -17,11 +17,25 @@ templateObjectSchema = atapi.Schema((
         widget=atapi.SelectionWidget()
     ),
 
+    atapi.TextField('submitBody',
+        required = False,
+        searchable = True,
+        primary = False,
+        validators = ('isTidyHtmlWithCleanup',),
+        default='Enter information here to register',
+        #validators = ('isTidyHtml',),
+        default_output_type = 'text/x-html-safe',
+        widget = atapi.RichWidget(
+            description = '',
+            rows = 25,
+        ),
+    ),
+
     atapi.StringField(
         name='thanksTitle',
         required=0,
         searchable=0,
-        default='',
+        default='Thank you!',
     ),
 
     atapi.TextField('thanksBody',
@@ -30,6 +44,7 @@ templateObjectSchema = atapi.Schema((
         primary = False,
         validators = ('isTidyHtmlWithCleanup',),
         #validators = ('isTidyHtml',),
+        default='Thank you for registering',
         default_output_type = 'text/x-html-safe',
         widget = atapi.RichWidget(
             description = '',
@@ -42,10 +57,20 @@ templateObjectSchema = atapi.Schema((
         required=0,
         searchable=0,
         mutator='setAllowAnonymousAdd',
-        mode='r',
+#        mode='r',
         default=True,
     ),
 
+# Re-enable when member adding is mature
+#    atapi.BooleanField(
+#        name='allowMemberAdd',
+#        required=0,
+#        searchable=0,
+#        mutator='setAllowMemberAdd',
+##        mode='r',
+#        default=False,
+#    ),
+
     atapi.LinesField(
         name='tableListingFields',
         required=0,
@@ -110,6 +135,7 @@ class MegamanicEditable:
         for name in request.get('megamanic_edit_hack_request', []):
             del request.form[name]
 
+    security.declarePublic('isMegamanicEditableTemplateObject')
     def isMegamanicEditableTemplateObject(self, object=None):
         """Returns true if we're a template object."""
         return False
@@ -132,8 +158,18 @@ class MegamanicEditableTemplateObject(MegamanicEditable):
     security = ClassSecurityInfo()
     implements(MegamanicEditableTemplateObject)
 
+    security.declarePublic('getMEAddLimitReached')
+    def MEAddLimitReached(self):
+        """Returns the max number of megamanic_add added objects."""
+        try:
+            return self.getParentNode().MEAddLimitReached()
+        except AttributeError:
+            return False
+
     def manage_afterAdd(self, item, container):
         """Adds necessary things.."""
+        # Why AT default doesn't kick in beats me
+        self.setTableListingFields(('title', 'description'))
         try:
             try:
                 self.invokeFactory(id='added', type_name='Large Plone Folder', title='Add Objects')
@@ -160,7 +196,7 @@ class MegamanicEditableTemplateObject(MegamanicEditable):
             return None
         if allow:
             self.added.manage_permission('Add portal content', roles=['Anonymous'])
-            self.added.manage_permission('View', roles=['Anonymous'])
+            self.added.manage_permission('View', roles=['Editor', 'Manager', 'Owner',], acquire=0)
             self.added.manage_permission('Access contents information', roles=['Anonymous'])
             for content in self.contentValues():
                 if content.id != 'added':
@@ -175,6 +211,31 @@ class MegamanicEditableTemplateObject(MegamanicEditable):
                     content.manage_permission('View', roles=[], acquire=1)
                     content.manage_permission('Access contents information', roles=[], acquire=1)
 
+    def setAllowMemberAdd(self, allow=False):
+        """Set allow member add if necessary."""
+        self.schema['allowMemberAdd'].set(self, allow)
+        if not hasattr(self.aq_base, 'added'):
+            # Before manage_afterAdd
+            return None
+        # Assuming that property gets set before this one
+        if self.getAllowAnonymousAdd(): return
+        if allow:
+            self.added.manage_permission('Add portal content', roles=['Member', 'Manager'])
+            self.added.manage_permission('View', roles=['Editor', 'Manager', 'Owner',], acquire=0)
+            self.added.manage_permission('Access contents information', roles=['Member', 'Manager'])
+            for content in self.contentValues():
+                if content.id != 'added':
+                    content.manage_permission('View', roles=['Member', 'Manager'])
+                    content.manage_permission('Access contents information', roles=['Member', 'Manager'])
+        else:
+            self.added.manage_permission('Add portal content', roles=[], acquire=1)
+            self.added.manage_permission('View', roles=[], acquire=1)
+            self.added.manage_permission('Access contents information', roles=[], acquire=1)
+            for content in self.contentValues():
+                if content.id != 'added':
+                    content.manage_permission('View', roles=[], acquire=1)
+                    content.manage_permission('Access contents information', roles=[], acquire=1)
+
     def anonymousAllowedToViewEditWidget(self):
         """Returns a truth value if Anonymous can view edit widgets."""
         return False
